@@ -55,6 +55,18 @@ if FOAM_REF_VERSION( '>=', "010701" ):
     pass
 
 
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( '>=', "020000" ):
+    from chtMultiRegionFlux.r2_0_0 import *
+    pass
+
+
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( '>=', "020100" ):
+    from chtMultiRegionFlux.r2_1_0 import *
+    pass
+
+
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
