@@ -25,20 +25,15 @@
 
 
 #------------------------------------------------------------------------------------
-# To import corresponding plugin first
-#from Foam.applications.solvers.heatTransfer.chtMultiRegionFoam import plugin
-import derivedFvPatchFields
-
+from Foam import ref, man
 
 #-----------------------------------------------------------------------------------------------------------------------------------------------------------------------
 def readPIMPLEControls( runTime ):
 
-    from Foam.finiteVolume import fvSolution
-    solutionDict = fvSolution( runTime )
+    solutionDict = ref.fvSolution( runTime )
     
-    from Foam.OpenFOAM import word,readInt
-    pimple = solutionDict.subDict( word( "PIMPLE" ) )
-    nOuterCorr = readInt( pimple.lookup( word( "nOuterCorrectors" ) ) )
+    pimple = solutionDict.subDict( ref.word( "PIMPLE" ) )
+    nOuterCorr = pimple.lookupOrDefault( ref.word( "nOuterCorrectors" ), 1);
     
     return nOuterCorr
 
@@ -46,17 +41,15 @@ def readPIMPLEControls( runTime ):
 #--------------------------------------------------------------------------------------
 def setInitialMultiRegionDeltaT( adjustTimeStep, runTime, CoNum, DiNum, maxCo, maxDi, maxDeltaT ):
     if adjustTimeStep:
-       from Foam.OpenFOAM import GREAT, SMALL
-       if runTime.timeIndex() == 0 and ( CoNum > SMALL or DiNum > SMALL ) :
-          if CoNum == -GREAT:
-             CoNum = SMALL
+       if runTime.timeIndex() == 0 and ( CoNum > ref.SMALL or DiNum > ref.SMALL ) :
+          if CoNum < ref.SMALL:
+             CoNum = ref.SMALL
              pass
-          if DiNum == -GREAT:
-             DiNum = SMALL
+          if DiNum < ref.SMALL:
+             DiNum = ref.SMALL
              pass
           runTime.setDeltaT( min( min( maxCo / CoNum, maxDi / DiNum ) * runTime.deltaT().value(), maxDeltaT ) )
-          from Foam.OpenFOAM import ext_Info, nl
-          ext_Info() << "deltaT = " <<  runTime.deltaT().value() << nl
+          ref.ext_Info() << "deltaT = " <<  runTime.deltaT().value() << ref.nl
           pass
     return runTime, CoNum, DiNum
 
@@ -64,21 +57,19 @@ def setInitialMultiRegionDeltaT( adjustTimeStep, runTime, CoNum, DiNum, maxCo, m
 #--------------------------------------------------------------------------------------
 def setMultiRegionDeltaT( adjustTimeStep, runTime, CoNum, DiNum, maxCo, maxDi, maxDeltaT ):
     if adjustTimeStep:
-       from Foam.OpenFOAM import GREAT, SMALL
-       if CoNum == -GREAT:
-          CoNum = SMALL
+       if CoNum == -ref.GREAT:
+          CoNum = ref.SMALL
           pass
-       if DiNum == -GREAT:
-          DiNum = SMALL
+       if DiNum == -ref.GREAT:
+          DiNum = ref.SMALL
           pass
        
-       maxDeltaTFluid = maxCo / ( CoNum + SMALL )
-       maxDeltaTSolid = maxDi / ( DiNum + SMALL )
+       maxDeltaTFluid = maxCo / ( CoNum + ref.SMALL )
+       maxDeltaTSolid = maxDi / ( DiNum + ref.SMALL )
        
        deltaTFluid = min( min( maxDeltaTFluid, 1.0 + 0.1 * maxDeltaTFluid ), 1.2 );
        runTime.setDeltaT( min( min( deltaTFluid, maxDeltaTSolid ) * runTime.deltaT().value(), maxDeltaT ) )
-       from Foam.OpenFOAM import ext_Info, nl
-       ext_Info() << "deltaT = " <<  runTime.deltaT().value() << nl
+       ref.ext_Info() << "deltaT = " <<  runTime.deltaT().value() << ref.nl
        pass
     return runTime, CoNum, DiNum
 
@@ -86,34 +77,30 @@ def setMultiRegionDeltaT( adjustTimeStep, runTime, CoNum, DiNum, maxCo, maxDi, m
 #--------------------------------------------------------------------------------------
 def main_standalone( argc, argv ):
 
-    from Foam.OpenFOAM.include import setRootCase
-    args = setRootCase( argc, argv )
+    args = ref.setRootCase( argc, argv )
 
-    from Foam.OpenFOAM.include import createTime
-    runTime = createTime( args )
+    runTime = man.createTime( args )
     
-    from Foam.compressible import regionProperties
-    rp = regionProperties( runTime )
+    rp = ref.compressible.regionProperties( runTime )
     
     from fluid import createFluidMeshes
     fluidRegions = createFluidMeshes( rp, runTime )
-
+    
     from solid import createSolidMeshes,createSolidField
-    solidRegions=createSolidMeshes( rp,runTime )
+    solidRegions = createSolidMeshes( rp,runTime )
+    
 
     from fluid import createFluidFields
-
-    thermoFluid, rhoFluid, KFluid, UFluid, phiFluid, gFluid, turbulence, DpDtFluid, \
-                           initialMassFluid, ghFluid, ghfFluid, p_rghFluid = createFluidFields( fluidRegions, runTime )
+    thermoFluid, rhoFluid, kappaFluid, UFluid, phiFluid, gFluid, turbulence, KFluid, \
+                 dpdtFluid, initialMassFluid, ghFluid, ghfFluid, p_rghFluid, radiation = createFluidFields( fluidRegions, runTime )
 
     from solid import createSolidField
-    rhos, cps, rhosCps, Ks, Ts = createSolidField( solidRegions, runTime )
+    thermos = createSolidField( solidRegions, runTime )
     
     from fluid import initContinuityErrs
-    cumulativeContErr = initContinuityErrs( fluidRegions.size() )
+    cumulativeContErr = initContinuityErrs( fluidRegions )
     
-    from Foam.finiteVolume.cfdTools.general.include import readTimeControls
-    adjustTimeStep, maxCo, maxDeltaT = readTimeControls( runTime )
+    adjustTimeStep, maxCo, maxDeltaT = ref.readTimeControls( runTime )
     
     from solid import readSolidTimeControls
     maxDi= readSolidTimeControls( runTime )
@@ -122,35 +109,33 @@ def main_standalone( argc, argv ):
     CoNum = compressubibleMultiRegionCourantNo( fluidRegions, runTime, rhoFluid, phiFluid )
     
     from solid import solidRegionDiffusionNo
-    DiNum = solidRegionDiffusionNo( solidRegions, runTime, rhosCps, Ks )
+    DiNum = solidRegionDiffusionNo( solidRegions, runTime, thermos )
     
     runTime, CoNum, DiNum = setInitialMultiRegionDeltaT( adjustTimeStep, runTime, CoNum, DiNum, maxCo, maxDi, maxDeltaT )
 
-    from Foam.OpenFOAM import ext_Info, nl
     while runTime.run() :
-        adjustTimeStep, maxCo, maxDeltaT = readTimeControls(runTime)
+        adjustTimeStep, maxCo, maxDeltaT = ref.readTimeControls(runTime)
         
         maxDi= readSolidTimeControls( runTime )
         
         nOuterCorr = readPIMPLEControls( runTime )
         
-        from fluid import compressubibleMultiRegionCourantNo
         CoNum = compressubibleMultiRegionCourantNo( fluidRegions, runTime, rhoFluid, phiFluid )
 
-        DiNum = solidRegionDiffusionNo( solidRegions, runTime, rhosCps, Ks )
+        DiNum = solidRegionDiffusionNo( solidRegions, runTime, thermos )
            
         runTime, CoNum, DiNum = setMultiRegionDeltaT( adjustTimeStep, runTime, CoNum, DiNum, maxCo, maxDi, maxDeltaT )
                 
         runTime.increment()
         
-        ext_Info()<< "Time = " << runTime.timeName() << nl << nl;      
+        ref.ext_Info()<< "Time = " << runTime.timeName() << ref.nl << ref.nl
                 
         if nOuterCorr != 1 :
-            for i in range( fluidRegions.size() ):
+            for i in range( fluidRegions.__len__() ):
                 from fluid import setRegionFluidFields
-                mesh, thermo, rho, K, U, phi, turb, DpDt, p, psi, h, initialMass, p_rgh, gh, ghf = \
-                                     setRegionFluidFields( i, fluidRegions, thermoFluid, rhoFluid, KFluid, UFluid, \
-                                                           phiFluid, turbulence, DpDtFluid, initialMassFluid, ghFluid, ghfFluid, p_rghFluid )
+                mesh, thermo, rho, kappa, K, U, phi, turb, dpdt, p, psi, h, initialMass, p_rgh, gh, ghf, rad = \
+                                     setRegionFluidFields( i, fluidRegions, thermoFluid, rhoFluid, kappaFluid, UFluid, \
+                                                           phiFluid, turbulence, KFluid, dpdtFluid, initialMassFluid, ghFluid, ghfFluid, p_rghFluid, radiation )
                 
                 from fluid import storeOldFluidFields
                 storeOldFluidFields( p, rho )
@@ -159,44 +144,45 @@ def main_standalone( argc, argv ):
         
         # --- PIMPLE loop
         for oCorr in range( nOuterCorr ):
-            for i in range( fluidRegions.size() ):
-                ext_Info() << "\nSolving for fluid region " << fluidRegions[ i ].name() << nl
+            finalIter = ( oCorr == nOuterCorr-1 )
+            for i in range( fluidRegions.__len__() ):
+                ref.ext_Info() << "\nSolving for fluid region " << fluidRegions[ i ].name() << ref.nl
 
                 from fluid import setRegionFluidFields
-                mesh, thermo, rho, K, U, phi, turb, DpDt, p, psi, h, initialMass, p_rgh, gh, ghf = \
-                      setRegionFluidFields( i, fluidRegions, thermoFluid, rhoFluid, KFluid, UFluid, \
-                                            phiFluid, turbulence, DpDtFluid, initialMassFluid, ghFluid, ghfFluid, p_rghFluid )
+                mesh, thermo, rho, kappa, K, U, phi, turb, dpdt, p, psi, h, initialMass, p_rgh, gh, ghf, rad = \
+                      setRegionFluidFields( i, fluidRegions, thermoFluid, rhoFluid, kappaFluid, UFluid, \
+                                            phiFluid, turbulence, KFluid, dpdtFluid, initialMassFluid, ghFluid, ghfFluid, p_rghFluid, radiation )
                 
                 from fluid import readFluidMultiRegionPIMPLEControls
                 pimple, nCorr, nNonOrthCorr, momentumPredictor = readFluidMultiRegionPIMPLEControls( mesh ) 
                 
                 from fluid import solveFluid
-                cumulativeContErr = solveFluid( i, mesh, thermo, thermoFluid, rho, K, U, phi, h, turb, DpDt, p, psi, \
-                                                initialMass, p_rgh, gh, ghf, oCorr, nCorr, nOuterCorr, nNonOrthCorr, momentumPredictor, cumulativeContErr )
+                cumulativeContErr = solveFluid( i, mesh, thermo, rad, thermoFluid, rho, kappa, K, U, phi, h, turb, dpdt, p, psi, initialMass, p_rgh, gh, \
+                                                ghf, oCorr, nCorr, nOuterCorr, nNonOrthCorr, momentumPredictor, cumulativeContErr, finalIter )
                 
                 pass
                 
-            for i in range( solidRegions.size() ):
-               ext_Info() << "\nSolving for solid region " << solidRegions[ i ].name() << nl
+            for i in range( solidRegions.__len__() ):
+               ref.ext_Info() << "\nSolving for solid region " << solidRegions[ i ].name() << ref.nl
                
                from solid import setRegionSolidFields
-               mesh, rho, cp, K, T = setRegionSolidFields( i, solidRegions, rhos, cps, Ks, Ts )
+               mesh, thermo, rho, cp, tkappa, kappa = setRegionSolidFields( i, solidRegions, thermos )
                
                from solid import readSolidMultiRegionPIMPLEControls
                pimple, nNonOrthCorr = readSolidMultiRegionPIMPLEControls( mesh )
                
                from solid import solveSolid
-               solveSolid( mesh, rho, cp, K, T, nNonOrthCorr )
+               solveSolid( mesh, thermo, rho, cp, tkappa, kappa, nNonOrthCorr, finalIter )
                pass                
             pass
         pass
         runTime.write()
 
-        ext_Info()<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s" \
+        ref.ext_Info()<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s" \
             << "  ClockTime = " << runTime.elapsedClockTime() << " s" \
-            << nl << nl    
+            << ref.nl << ref.nl    
 
-    ext_Info() << "End\n"
+    ref.ext_Info() << "End\n"
     
     import os
     return os.EX_OK
@@ -205,15 +191,14 @@ def main_standalone( argc, argv ):
 #--------------------------------------------------------------------------------------
 argv = None
 import sys, os
-from Foam import FOAM_REF_VERSION
-if FOAM_REF_VERSION( "==", "010700" ):
+from Foam import FOAM_VERSION
+if FOAM_VERSION( ">=", "020100" ):
     if __name__ == "__main__" :
         argv = sys.argv
         os._exit( main_standalone( len( argv ), argv ) )
         pass
 else:
-    from Foam.OpenFOAM import ext_Info
-    ext_Info() << "\n\n To use this solver, it is necessary to SWIG OpenFOAM-1.7.0 \n"    
+    ref.ext_Info() << "\n\n To use this solver, it is necessary to SWIG OpenFOAM-2.1.0 or higher \n"    
     pass
 
 
